===============
Analysis module
===============

Tools to analyze neuronal networks, using either their topological properties,
their activity, or more importantly, taking both into account.


Content
=======

.. autosummary::

    nngt.analysis.adjacency_matrix
    nngt.analysis.assortativity
    nngt.analysis.bayesian_blocks
    nngt.analysis.betweenness_distrib
    nngt.analysis.binning
    nngt.analysis.closeness
    nngt.analysis.clustering
    nngt.analysis.degree_distrib
    nngt.analysis.diameter
    nngt.analysis.get_b2
    nngt.analysis.get_firing_rate
    nngt.analysis.get_spikes
    nngt.analysis.local_clustering
    nngt.analysis.node_attributes
    nngt.analysis.num_iedges
    nngt.analysis.num_scc
    nngt.analysis.num_wcc
    nngt.analysis.reciprocity
    nngt.analysis.spectral_radius
    nngt.analysis.subgraph_centrality
    nngt.analysis.total_firing_rate
    nngt.analysis.transitivity


.. automodule:: nngt.analysis
